@@ -9,6 +9,8 @@ from emmet.api.routes.electrodes.query_operators import (
     ElectrodeElementsQuery,
     ElectrodesChemsysQuery,
     WorkingIonQuery,
+    ElectrodeMultiMaterialIDQuery,
+    MultiBatteryIDQuery
 )
 
 from emmet.api.core.settings import MAPISettings
@@ -19,6 +21,8 @@ def insertion_electrodes_resource(insertion_electrodes_store):
         insertion_electrodes_store,
         InsertionElectrodeDoc,
         query_operators=[
+            MultiBatteryIDQuery(),
+            ElectrodeMultiMaterialIDQuery(),
             ElectrodeFormulaQuery(),
             ElectrodesChemsysQuery(),
             WorkingIonQuery(),
