@@ -3,6 +3,7 @@ from emmet.core.polar import PiezoelectricDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.piezo.query_operators import PiezoelectricQuery
+from emmet.api.routes.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.api.core.settings import MAPISettings
 
@@ -12,17 +13,16 @@ def piezo_resource(piezo_store):
         piezo_store,
         PiezoelectricDoc,
         query_operators=[
+            MultiMaterialIDQuery(),
             PiezoelectricQuery(),
             SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(
-                PiezoelectricDoc, default_fields=["material_id", "last_updated"]
-            ),
+            SparseFieldsQuery(PiezoelectricDoc, default_fields=["material_id", "last_updated"]),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Piezoelectric"],
         disable_validation=True,
-        timeout=MAPISettings().TIMEOUT
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
